@@ -5,7 +5,7 @@
 
     Transforms for LaTeX builder.
 
-    :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2019 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -26,7 +26,7 @@ URI_SCHEMES = ('mailto:', 'http:', 'https:', 'ftp:')
 
 class FootnoteDocnameUpdater(SphinxTransform):
     """Add docname to footnote and footnote_reference nodes."""
-    default_priority = 200
+    default_priority = 700
     TARGET_NODES = (nodes.footnote, nodes.footnote_reference)
 
     def apply(self):
@@ -596,3 +596,40 @@ class DocumentTargetTransform(SphinxTransform):
             section = node.next_node(nodes.section)
             if section:
                 section['ids'].append(':doc')  # special label for :doc:
+
+
+class IndexInSectionTitleTransform(SphinxTransform):
+    """Move index nodes in section title to outside of the title.
+
+    LaTeX index macro is not compatible with some handling of section titles
+    such as uppercasing done on LaTeX side (cf. fncychap handling of ``\\chapter``).
+    Moving the index node to after the title node fixes that.
+
+    Before::
+
+        <section>
+            <title>
+                blah blah <index entries=[...]/>blah
+            <paragraph>
+                blah blah blah
+            ...
+
+    After::
+
+        <section>
+            <title>
+                blah blah blah
+            <index entries=[...]/>
+            <paragraph>
+                blah blah blah
+            ...
+    """
+    default_priority = 400
+
+    def apply(self):
+        for node in self.document.traverse(nodes.title):
+            if isinstance(node.parent, nodes.section):
+                for i, index in enumerate(node.traverse(addnodes.index)):
+                    # move the index node next to the section title
+                    node.remove(index)
+                    node.parent.insert(i + 1, index)
