@@ -5,12 +5,14 @@
 
     Pattern-matching utility functions for Sphinx.
 
-    :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2019 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 import re
 
+from sphinx.util.osutil import canon_path
+
 if False:
     # For type annotation
     from typing import Callable, Dict, List, Match, Pattern  # NOQA
@@ -86,6 +88,7 @@ class Matcher(object):
 
     def match(self, string):
         # type: (unicode) -> bool
+        string = canon_path(string)
         return any(pat(string) for pat in self.patterns)
 
 
